==> wire-grpc-client-3.2.0-javadoc.jar: wire-schema/com.squareup.wire.schema/-syntax-rules/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema](../index.md) / [SyntaxRules](./index.md)

# SyntaxRules

`interface SyntaxRules`

A set of rules which defines schema requirements for a specific [Syntax](../-proto-file/-syntax/index.md).

### Functions

| Name | Summary |
|---|---|
| [allowUserDefinedDefaultValue](allow-user-defined-default-value.md) | `abstract fun allowUserDefinedDefaultValue(): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [canExtend](can-extend.md) | `abstract fun canExtend(protoType: `[`ProtoType`](../-proto-type/index.md)`): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [enumRequiresZeroValueAtFirstPosition](enum-requires-zero-value-at-first-position.md) | `abstract fun enumRequiresZeroValueAtFirstPosition(): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [getEncodeMode](get-encode-mode.md) | `abstract fun getEncodeMode(protoType: `[`ProtoType`](../-proto-type/index.md)`, label: `[`Label`](../-field/-label/index.md)`?, isPacked: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): `[`EncodeMode`](../-field/-encode-mode/index.md) |
| [isPackedByDefault](is-packed-by-default.md) | `abstract fun isPackedByDefault(type: `[`ProtoType`](../-proto-type/index.md)`, label: `[`Label`](../-field/-label/index.md)`?): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |

### Companion Object Functions

| Name | Summary |
|---|---|
| [get](get.md) | `fun get(syntax: `[`Syntax`](../-proto-file/-syntax/index.md)`?): `[`SyntaxRules`](./index.md) |

==> wire-grpc-client-3.2.2-javadoc.jar: wire-schema/com.squareup.wire.schema/-syntax-rules/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema](../index.md) / [SyntaxRules](./index.md)

# SyntaxRules

`interface SyntaxRules`

A set of rules which defines schema requirements for a specific [Syntax](../-proto-file/-syntax/index.md).

### Functions

| Name | Summary |
|---|---|
| [allowUserDefinedDefaultValue](allow-user-defined-default-value.md) | `abstract fun allowUserDefinedDefaultValue(): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [canExtend](can-extend.md) | `abstract fun canExtend(protoType: `[`ProtoType`](../-proto-type/index.md)`): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [enumRequiresZeroValueAtFirstPosition](enum-requires-zero-value-at-first-position.md) | `abstract fun enumRequiresZeroValueAtFirstPosition(): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [getEncodeMode](get-encode-mode.md) | `abstract fun getEncodeMode(protoType: `[`ProtoType`](../-proto-type/index.md)`, label: `[`Label`](../-field/-label/index.md)`?, isPacked: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): `[`EncodeMode`](../-field/-encode-mode/index.md) |
| [isPackedByDefault](is-packed-by-default.md) | `abstract fun isPackedByDefault(type: `[`ProtoType`](../-proto-type/index.md)`, label: `[`Label`](../-field/-label/index.md)`?): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [jsonName](json-name.md) | `abstract fun jsonName(name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`): `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |

### Companion Object Functions

| Name | Summary |
|---|---|
| [get](get.md) | `fun get(syntax: `[`Syntax`](../-proto-file/-syntax/index.md)`?): `[`SyntaxRules`](./index.md) |
